# Azul game engine

Disclaimer: I am not the creator of this game, creator is Michael Kiesling.
I am writing this game as a lib to enable AI training, API etc. on this good game.

Original game: [https://en.wikipedia.org/wiki/Azul_(board_game)](Azul).

[![codecov](https://codecov.io/gh/AzulImplementation/AzulGameEngine/branch/main/graph/badge.svg)](https://codecov.io/gh/AzulImplementation/AzulGameEngine)